pynrc.logging\_utils.FilterLevelRange
=====================================

.. currentmodule:: pynrc.logging_utils

.. autoclass:: FilterLevelRange
   :members:
   :inherited-members:
   :show-inheritance:

   
   .. automethod:: __init__

   
   .. rubric:: Methods

   .. autosummary::
   
      ~FilterLevelRange.__init__
      ~FilterLevelRange.filter
   
   

   
   
   